summaryrefslogtreecommitdiff
path: root/source4/autogen.sh
diff options
context:
space:
mode:
authorStefan Metzmacher <metze@samba.org>2004-04-14 08:37:07 +0000
committerGerald (Jerry) Carter <jerry@samba.org>2007-10-10 12:51:17 -0500
commit1ac201024b104b2e6bd331255870fc39db657eec (patch)
treefef967414d4d6e6b56c07844579da7f0f014d210 /source4/autogen.sh
parentdda81bdb9262b95da9412e18bdd6d0820b77587c (diff)
downloadsamba-1ac201024b104b2e6bd331255870fc39db657eec.tar.gz
samba-1ac201024b104b2e6bd331255870fc39db657eec.tar.bz2
samba-1ac201024b104b2e6bd331255870fc39db657eec.zip
r206: - we know use SVN not CVS:-)
- we should cleanup the cache before and after autoconf metze (This used to be commit 114f5198a7e73af5c62fe83145f836588ed365fe)
Diffstat (limited to 'source4/autogen.sh')
-rwxr-xr-xsource4/autogen.sh8
1 files changed, 5 insertions, 3 deletions
diff --git a/source4/autogen.sh b/source4/autogen.sh
index aa8534858e..922cad8e61 100755
--- a/source4/autogen.sh
+++ b/source4/autogen.sh
@@ -1,6 +1,6 @@
#!/bin/sh
# Run this script to build samba from CVS.
## insert all possible names (only works with
## autoconf 2.x
@@ -43,20 +43,22 @@ done
## do we have it?
##
if [ "$AUTOCONFFOUND" = "0" -o "$AUTOHEADERFOUND" = "0" ]; then
- echo "$0: need autoconf 2.53 or later to build samba from CVS" >&2
+ echo "$0: need autoconf 2.53 or later to build samba from SVN" >&2
exit 1
fi
echo "$0: running script/mkversion.sh"
./script/mkversion.sh || exit 1
+rm -rf autom4te*.cache
+
echo "$0: running $AUTOHEADER"
$AUTOHEADER || exit 1
echo "$0: running $AUTOCONF"
$AUTOCONF || exit 1
-rm -rf autom4te.cache autom4te-2.53.cache
+rm -rf autom4te*.cache
echo "Now run ./configure and then make."
exit 0
@@ -1,6 +1,6 @@
#!/bin/sh
-# Run this script to build samba from CVS.
+# Run this script to build samba from SVN.
## insert all possible names (only works with
## autoconf 2.x